Raiden Network |capitalized_version| Documentation
**************************************************


This is the documentation for the |version| version of the `Raiden Network <http://raiden.network/>`_. You can find the source code in `our Github Repository <https://github.com/raiden-network/raiden>`_.

What is the Raiden Network?
---------------------------
The Raiden Network is an off-chain scaling solution, enabling near-instant, low-fee and scalable payments. It’s complementary to the Ethereum blockchain and works with any ERC20 compatible token. The Raiden project is work in progress. Its goal is to research state channel technology, define protocols and develop reference implementations.

Where to start?
---------------
If this is your first encounter with the Raiden Network it is recommended to first take a look at the :doc:`Installation Guide<overview_and_guide>`. Once a Raiden node is up and running you can go try out :doc:`the Web UI<webui_tutorial>`. If you want a more in depth guide on how to start using the Raiden API you should check out the :doc:`Getting started with the Raiden API<api_walkthrough>` guide.

Disclaimer
----------
The following content may contain views and opinions, errors and omissions by which the content creator(s) and any represented organizations cannot be held liable. The wording and concepts regarding financial terminology (e.g. “payments”, “checks”, “currency”, “transfer” [of value]) are exclusively used in an exemplary way to describe technological principles and do not necessarily conform to the real world or legal equivalents of these terms and concepts.

Contents
********

.. toctree::
  :maxdepth: 2

  overview_and_guide
  api_walkthrough
  rest_api
  red_eyes_mainnet_tutorial
  webui_tutorial
  config_file
  onboarding
  state_machines
  changelog
  glossary
  trademarks
  Raiden Codebase Documentation <./_build/generated/modules>
